@@ -11,7 +11,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2020-2021 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2020-2023 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -29,35 +29,59 @@
 # ==================================================================================================================== #
 #
 """Module for CI service base classes."""
-from dataclasses  import make_dataclass, dataclass
+from dataclasses  import make_dataclass
 from datetime     import datetime
 from os           import environ
-from typing       import Dict
+from typing       import Dict, Optional as Nullable
 
-from pyVersioning import SelfDescriptive
+from pyTooling.Decorators import export
+from pyTooling.MetaClasses import ExtendedType, abstractmethod
+
+from pyVersioning import SelfDescriptive, GitHelper, GitShowCommand
 
 
+@export
 class ServiceException(Exception):
-	pass
+	""".. todo:: ServiceException needs documentation"""
 
 
-@dataclass
+@export
 class Platform(SelfDescriptive):
-	ci_service : str
+	""".. todo:: Platform needs documentation"""
+
+	_ciService: str
 
 	_public = ['ci_service']
 
+	def __init__(self, ciService: str):
+		self._ciService = ciService
 
-class CIService:
-	ENV_INCLUDE_FILTER =  ()
-	ENV_EXCLUDE_FILTER =  ()
-	ENV_INCLUDES =        []
-	ENV_EXCLUDES =        []
+	@property
+	def ci_service(self) -> str:
+		return self._ciService
 
+
+@export
+class BaseService(metaclass=ExtendedType):
+	"""Base-class to collect platform and environment information from e.g. environment variables."""
+
+	@abstractmethod
 	def getPlatform(self) -> Platform:
-		raise NotImplementedError()
+		""".. todo:: getPlatform needs documentation"""
+
+
+@export
+class CIService(BaseService, GitHelper):
+	"""Base-class to collect Git and other platform and environment information from CI service environment variables."""
+
+	ENV_INCLUDE_FILTER = ()
+	ENV_EXCLUDE_FILTER = ()
+	ENV_INCLUDES =       []
+	ENV_EXCLUDES =       []
 
 	def getEnvironment(self) -> Dict[str, str]:
+		""".. todo:: getEnvironment needs documentation"""
+
 		filteredEnv = {key:value for (key,value) in environ.items() if key.startswith(self.ENV_INCLUDE_FILTER) and not key.endswith(self.ENV_EXCLUDE_FILTER)}
 
 		# manually add some variables
@@ -83,31 +107,40 @@ class CIService:
 			[(name, str) for name in filteredEnv.keys()],
 			bases=(SelfDescriptive,),
 			namespace={
-				'as_dict':        lambda self: filteredEnv,
-				'Keys':           lambda self: filteredEnv.keys(),
-				'KeyValuePairs':  lambda self: func(self)
+				'as_dict':       lambda self: filteredEnv,
+				'Keys':          lambda self: filteredEnv.keys(),
+				'KeyValuePairs': lambda self: func(self)
 			},
 			repr=True
 		)
 
 		return Environment(**filteredEnv)
 
+	@abstractmethod
 	def getGitHash(self) -> str:
-		raise NotImplementedError()
+		""".. todo:: getGithash needs documentation"""
 
+	# @abstractmethod
 	def getCommitDate(self) -> datetime:
-		raise NotImplementedError()
+		""".. todo:: getCommitDate needs documentation"""
 
-	def getGitBranch(self) -> str:
-		raise NotImplementedError()
+		datetimeString = self.execGitShow(GitShowCommand.CommitDateTime, self.getGitHash())
+		return datetime.fromtimestamp(int(datetimeString))
 
-	def getGitTag(self) -> str:
-		raise NotImplementedError()
+	@abstractmethod
+	def getGitBranch(self) -> Nullable[str]:
+		""".. todo:: getGitBranch needs documentation"""
 
+	@abstractmethod
+	def getGitTag(self) -> Nullable[str]:
+		""".. todo:: getGitTag needs documentation"""
+
+	@abstractmethod
 	def getGitRepository(self) -> str:
-		raise NotImplementedError()
+		""".. todo:: getGitRepository needs documentation"""
 
 
-class WorkStation(CIService):
+@export
+class WorkStation(BaseService):
 	def getPlatform(self) -> Platform:
 		return Platform("NO-CI")
