@@ -11,7 +11,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2020-2021 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2020-2023 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -29,41 +29,46 @@
 # ==================================================================================================================== #
 #
 """Travis  specific code to collect the build environment."""
-from os import environ
+from os     import environ
+from typing import Optional as Nullable, Dict
+
+from pyTooling.Decorators import export
 
 from pyVersioning.CIService import CIService, Platform, ServiceException
 
 
+@export
 class Travis(CIService):
-	ENV_INCLUDE_FILTER =  ("TRAVIS_")
-	ENV_EXCLUDE_FILTER =  ("_TOKEN")
-	ENV_INCLUDES =        ['CI', 'CONTINUOUS_INTEGRATION', 'TRAVIS']
-	ENV_EXCLUDES =        []
+	"""Collect Git and other platform and environment information from environment variables provided by Travis-CI."""
+
+	ENV_INCLUDE_FILTER = ("TRAVIS_", )
+	ENV_EXCLUDE_FILTER = ("_TOKEN", )
+	ENV_INCLUDES =       ('CI', 'CONTINUOUS_INTEGRATION', 'TRAVIS')
+	ENV_EXCLUDES =       []
 
 	def getPlatform(self) -> Platform:
 		return Platform("travis")
 
+	def getEnvironment(self) -> Dict[str, str]:
+		return {}
+
 	def getGitHash(self) -> str:
 		try:
 			return environ['TRAVIS_COMMIT']
 		except KeyError as ex:
 			raise ServiceException from ex
 
-	def getGitBranch(self) -> str:
+	def getGitBranch(self) -> Nullable[str]:
 		try:
 			return environ['TRAVIS_BRANCH']
 		except KeyError:
-			pass
+			return None
 
-		return None
-
-	def getGitTag(self) -> str:
+	def getGitTag(self) -> Nullable[str]:
 		try:
 			return environ['TRAVIS_TAG']
 		except KeyError:
-			pass
-
-		return None
+			return None
 
 	def getGitRepository(self) -> str:
 		try:
